init_topology

Function init_topology 

pub fn init_topology(skel: &mut OpenBpfSkel<'_>) -> Result<TopologyPlan>
Phase 1 (pre-load): discover the topology and write the rodata globals.

Returns the plans for the caller to pass to the populate functions after the object is loaded.