pub fn init_topology(skel: &mut OpenBpfSkel<'_>) -> Result<TopologyPlan>Expand description
Phase 1 (pre-load): discover the topology and write the rodata globals.
Returns the plans for the caller to pass to the populate functions after the object is loaded.